(define (script-fu-drop theImage origLayer theRadius theColor)

	(let* 
		(
			(currentWidth (car (gimp-image-width theImage)))
			(currentHeight (car (gimp-image-height theImage)))
			(newWidth (+ currentWidth (* 2 theRadius)))
			(newHeight (+ currentHeight (* 2 theRadius)))
		)

		(gimp-image-resize 
			theImage
			newWidth
			newHeight
			0			;x offset
			0			;y offset
		)

		; (gimp-image-undo-group-start theImage)

		; Create layer for shadow
		(set! shadowLayer 	
			(car (gimp-layer-new 
						theImage
						newWidth
						newHeight
						1
						"Shadow"
						100
						NORMAL-MODE)
		 	)
		)

		(gimp-image-add-layer theImage shadowLayer 0)

		(gimp-edit-clear shadowLayer) 

		(gimp-image-set-active-layer theImage shadowLayer)

		; select content of layer if no selection exists
		(if (not (= 0 (car (gimp-selection-is-empty theImage))))
			(begin
				(gimp-selection-layer-alpha origLayer)
			)
		)

		(gimp-context-set-foreground theColor)

		(gimp-edit-fill shadowLayer FOREGROUND-FILL)

		(gimp-selection-none theImage)

		(plug-in-gauss-iir2 1 theImage shadowLayer theRadius theRadius)

		(gimp-image-lower-layer theImage shadowLayer)

		(gimp-drawable-offset shadowLayer 0 1 (/ theRadius 4) (/ theRadius 4))

		(gimp-layer-set-opacity shadowLayer 60)

		; (gimp-image-undo-group-end theImage)

		(gimp-displays-flush)		; flush (refresh) the display

		; (gimp-message (number->string newWidth 10))

	)
)

(script-fu-register "script-fu-drop"			; name of main function
			_"Drop-Shadow..."					; name of script in menu
			"Add a drop-shadow"					; description
			"Eric Pierce"						; author
			"GPL"								; copyright
			"2005.09.06"						; date
			"RGBA"								; supported color spaces
			SF-IMAGE		"Image"				0
			SF-DRAWABLE		"Layer"				0

			SF-ADJUSTMENT	_"Blur radius"		'(15 0 100 1 10 0 0)  
			;'(value, lower, upper, step_inc, page_inc, digits after decimal, type)

			SF-COLOR		_"Color"			'(0 0 0)
)

(script-fu-menu-register "script-fu-drop"
			_"<Image>/S_hadow")
